Installs GoodJob by creating the necessary database migrations.
mix good_job.installThis will create a migration file for the GoodJob tables.
Installs GoodJob by creating the necessary database migrations.
mix good_job.installThis will create a migration file for the GoodJob tables.